threading.Thread

Module threading :: Class Thread |
[show private | hide private]
[frames | no frames]

## Type Thread

    object --+
             |
      _Verbose --+
                 |
                Thread

Known Subclasses:
  `SpoonTransportThread`

Method Summary
| `__init__(self, group, target, name, args, kwargs, verbose)`
(type, value, traceback) | ``__exc_info`()` Return information about the most recent exception caught by an except clause in the current stack frame or in an older stack frame.
| `__repr__(self)`
| `getName(self)`
| `isAlive(self)`
| `isDaemon(self)`
| `join(self, timeout)`
| `run(self)`
| `setDaemon(self, daemonic)`
| `setName(self, name)`
| `start(self)`
| `__bootstrap(self)`
| ``__delete`(self)` Remove current thread from the dict of currently running threads.
| `__stop(self)`
| `_set_daemon(self)`
Inherited from _Verbose
| ``_note`(self, format, *args)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Class Variable Summary
`bool` | `_Thread__initialized` = `False`

Method Details

### __delete(self) Remove current thread from the dict of currently running threads.

Class Variable Details

    ### _Thread__initialized Type: `bool` Value:
        False

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net